use master
GO

CREATE DATABASE [DWH_tool]
GO

USE [DWH_tool]
GO
/****** Object:  UserDefinedFunction [dbo].[sfn_get_ExecutionID_from_sysjobhistory]     ******/
CREATE FUNCTION [dbo].[sfn_get_ExecutionID_from_sysjobhistory]
				( @instance_id int)  -- each Jobstep-execution has a diferent instance_id

RETURNS Int
AS
BEGIN

Declare @tempString      NVARCHAR(4)
Declare @ssisExecutionID Int 

    Set @tempString = ( Select SubString( [message]
									    , (Patindex('%Execution ID:%', [message]) + 14)
										, (Patindex('%.  To view the details for the execution%', [message])
										 - (Patindex('%Execution ID:%', [message]) + 14))
										)
					    From   msdb.dbo.sysjobhistory
						Where  [message] like '%Execution ID:%'
						  and  instance_id = @instance_id
                           )
    
	-- additional cleaning for "error"-messages
	Set @tempString = Replace( @tempString, ',', '')


    IF IsNumeric( @tempString ) = 1
	   Set @ssisExecutionID = CAST( @tempString as INT )
    ELSE
	   Set @ssisExecutionID = NULL
-- Return the result of the function
RETURN @ssisExecutionID

END  -- end Function
GO
/****** Object:  UserDefinedFunction [dbo].[sfn_max_ExecutionID_from_CatalogExecutions]  ******/
CREATE FUNCTION [dbo].[sfn_max_ExecutionID_from_CatalogExecutions](
                    @folder_name   sysname        = null
				  , @project_name  sysname 	      = null
                  , @package_name  nvarchar(260)  = null
                  )
RETURNS BigINT

AS
BEGIN
	DECLARE @max_exec_id BigINT

	IF (   @folder_name   is Null
	   or  @project_name  is Null
	   or  @package_name  is NUll )
		SET @max_exec_id = ( SELECT max(execution_id)
							 FROM   SSISDB.catalog.executions )    
	ELSE
		SET @max_exec_id = ( SELECT max(execution_id)
							 FROM   SSISDB.catalog.executions
							 WHERE  folder_name  = @folder_name
							   AND  project_name = @project_name
							   AND  package_name = @package_name )
    -- END IF

    ---- Return the result of the function
	RETURN @max_exec_id

END  -- end FUNCTION
-- http://technet.microsoft.com/de-de/library/ff878089.aspx
GO
/****** Object:  UserDefinedFunction [dbo].[sfn_max_ExecutionID_from_sysjobhistory]    ******/
CREATE FUNCTION [dbo].[sfn_max_ExecutionID_from_sysjobhistory]()

RETURNS Int
AS
BEGIN
	Declare @maxExecutionID Int

    Set @maxExecutionID = ( Select CAST( SubString( [message]
									              , (Patindex('%Execution ID:%', [message]) + 14)
											      , (Patindex('%.  To view the details for the execution%', [message])
												    - (Patindex('%Execution ID:%', [message]) + 14))
											      )
							       as Int )			   
						    From   msdb.dbo.sysjobhistory
						    Where  [message] like '%Execution ID:%'
						      and  instance_id = ( select max(instance_id) 
											       from   msdb.dbo.sysjobhistory
											       where  [message] like '%Execution ID:%'
											         and  [message] like '%To view the details for the execution%')
                          )

	-- Return the result of the function
	RETURN @maxExecutionID

END  -- end Function
GO
/****** Object:  UserDefinedFunction [dbo].[tfn_SSISDB_execution_data_statistics]    ******/
CREATE FUNCTION [dbo].[tfn_SSISDB_execution_data_statistics] 
(
	@execution_id   bigint = null
)
RETURNS 
@RETURN_execution_data_statistics TABLE 
(
    execution_id 	     bigint
  ,	package_name 	     nvarchar(260) 	 
  , task_name 	         nvarchar(4000) 	 
  , dataflow_path_name 	 nvarchar(4000) 	 
  , rows_sent 	         bigint 	        
)
AS
BEGIN
    IF  @execution_id IS NOT NULL
		INSERT  @RETURN_execution_data_statistics
		SELECT  execution_id, package_name, task_name, dataflow_path_name, SUM(rows_sent) as 'rows_sent'
		FROM    SSISDB.catalog.execution_data_statistics
		WHERE   execution_id = @execution_id
		GROUP   By execution_id, package_name, task_name, dataflow_path_name
	    ORDER   By execution_id, package_name, task_name, dataflow_path_name
    ELSE
	    INSERT  @RETURN_execution_data_statistics
		SELECT  execution_id, package_name, task_name, dataflow_path_name, SUM(rows_sent) as 'rows_sent'
		FROM    SSISDB.catalog.execution_data_statistics
		GROUP   By execution_id, package_name, task_name, dataflow_path_name
	    ORDER   By execution_id, package_name, task_name, dataflow_path_name

    ------
	RETURN 
END  -- end Function
GO
/****** Object:  UserDefinedFunction [dbo].[tfn_SSISDB_execution_id_max_rows_sent]    ******/
CREATE FUNCTION [dbo].[tfn_SSISDB_execution_id_max_rows_sent]
                ( @execution_id   bigint = null )

RETURNS 
@RETURN_execution_data_statistics TABLE 
(
    execution_id 	     bigint
  , rows_sent 	         bigint 	        
)
AS
BEGIN
    IF  @execution_id IS NOT NULL
		INSERT  @RETURN_execution_data_statistics
		SELECT  execution_id, MAX(rows_sent) as 'rows_sent'
		FROM    SSISDB.catalog.execution_data_statistics
		WHERE   execution_id = @execution_id
		GROUP   By execution_id
	    ORDER   By execution_id
    ELSE
	    INSERT  @RETURN_execution_data_statistics
		SELECT  NULL, NULL

    ------
	RETURN 
END  -- end Function
GO
/****** Object:  StoredProcedure [dbo].[get_SSIS_Variables]     ******/
CREATE PROC  [dbo].[get_SSIS_Variables]  
             @file  varchar(255)
AS
BEGIN

Declare @charVar varChar(max)
      , @nameSp  varChar(400)
      , @sqlCmd  varChar(400)
      , @xmlVar  xml

Declare @tmpTable Table (col1 varchar(max))
Set @sqlCmd  = ' Select * From OPENROWSET ( BULK ''' + @file + ''', SINGLE_BLOB ) AS x ';

Insert Into @tmpTable
exec( @sqlCmd )

Set  @xmlVar = ( select Top(1) col1 from @tmpTable );
--select @xmlVar
----

Declare @i int;  -- idoc

Execute sp_xml_preparedocument @i OutPut
                             , @xmlVar
        , '<DTS:Executable xmlns:DTS="www.microsoft.com/SqlServer/Dts"/>'
       
---- Variables ------------------------------------------------------------
SELECT @file                                                                       as 'flName'
     --, Props.Prop.query('.')
     , Props.Prop.value('declare namespace n1="www.microsoft.com/SqlServer/Dts";
	                     string(./../@n1:ObjectName)','nvarchar(max)')             as 'Variable'
     , Props.Prop.value('declare namespace n1="www.microsoft.com/SqlServer/Dts";
	                     string(./../@n1:Namespace)','nvarchar(max)')              as 'Namespace'
     , Props.Prop.value('declare namespace n1="www.microsoft.com/SqlServer/Dts";
	                     string(./@n1:DataType)','nvarchar(max)')                  as 'DataType'
     , Props.Prop.value('.', 'nvarchar(max)')                                      as 'DefaultValue'
FROM   @xmlVar.nodes('declare namespace DTS="www.microsoft.com/SqlServer/Dts";
                      /DTS:Executable/DTS:Variables/DTS:Variable/DTS:VariableValue') Props(Prop)

Execute sp_xml_removedocument @i


END  -- end proc
GO
/****** Object:  StoredProcedure [dbo].[get_User_Objects]    ******/
CREATE Proc [dbo].[get_User_Objects]
            @dbName sysname 
AS 
BEGIN

    DECLARE @sqlCmd nvarchar(4000)

    Set @sqlCmd = '	SELECT ''' + @dbName + '''   as ''db_name''
						 , name      as ''object_name''
						 , type
						 , type_desc
						 , create_date
						 , modify_date
					FROM  [' + @dbName + '].sys.objects
					WHERE  object_id >= 100
					  and  type_desc != ''INTERNAL_TABLE''
					ORDER  by type_desc, name  '

	---- RETURN
	exec sp_executesql @sqlCmd 
	
END  --  end Proc
GO
